#!/usr/bin/env bash

FILE_PATH="nordpass_32"

if [[ $(uname -m) == 'x86_64' ]]; then
    FILE_PATH="nordpass"
fi

UpdateAppPath() {
    APP_PATH="$1/nordpass"
    ESCAPED_APP_PATH=${APP_PATH////\\/}
    sed -i -e "s/APP_PATH/$ESCAPED_APP_PATH/" "$1/com.nordsec.nordpass.json"
    rm "$1/com.nordsec.nordpass.json-e" #os-x creates backup for sed.. remove it
}

CopyFilesTo() {
    mkdir -p "$1" > /dev/null 2>&1 &&
    mkdir -p "$1/nordpass-logs" > /dev/null 2>&1 &&
    cp ./nordpass.json "$1/com.nordsec.nordpass.json" > /dev/null 2>&1 &&
    cp "./${FILE_PATH}" "$1/nordpass" > /dev/null 2>&1 &&
    UpdateAppPath "$1" > /dev/null 2>&1 ||
      echo "skip $1" > /dev/null
}

set -e

cp ./nordpass.dist.json ./nordpass.json

if [[ "$(uname -s)" = "Darwin" ]]; then
    # chrome
    CopyFilesTo ~/Library/Application\ Support/Google/Chrome/NativeMessagingHosts
    CopyFilesTo /Library/Google/Chrome/NativeMessagingHosts

    # chromium
    CopyFilesTo ~/Library/Application\ Support/Chromium/NativeMessagingHosts
    CopyFilesTo /Library/Application\ Support/Chromium/NativeMessagingHosts

    # brave
    CopyFilesTo ~/Library/Application\ Support/BraveSoftware/Brave-Browser/NativeMessagingHosts
    CopyFilesTo /Library/Application\ Support/BraveSoftware/Brave-Browser/NativeMessagingHosts

    # vivaldi
    CopyFilesTo ~/Library/Application\ Support/Vivaldi/vivaldi/NativeMessagingHosts
    CopyFilesTo /Library/Application\ Support/Vivaldi/vivaldi/NativeMessagingHosts

    sed -i -e "/allowed_origins/d" ./nordpass.json

    # mozilla
    CopyFilesTo ~/Library/Application\ Support/Mozilla/NativeMessagingHosts
    CopyFilesTo /Library/Application\ Support/Mozilla/NativeMessagingHosts
else
    # chrome
    CopyFilesTo ~/.config/google-chrome/NativeMessagingHosts
    CopyFilesTo /etc/opt/chrome/native-messaging-hosts

    # chromium
    CopyFilesTo ~/.config/chromium/NativeMessagingHosts
    CopyFilesTo ~/snap/chromium/current/.config/chromium/NativeMessagingHosts
    CopyFilesTo /etc/chromium/native-messaging-hosts

    # brave
    CopyFilesTo ~/.config/BraveSoftware/Brave-Browser/NativeMessagingHosts

    # vivaldi
    CopyFilesTo ~/.config/vivaldi/NativeMessagingHosts

    sed -i -e "/allowed_origins/d" ./nordpass.json

    # mozilla
    CopyFilesTo ~/.mozilla/native-messaging-hosts
    CopyFilesTo /usr/lib/mozilla/native-messaging-hosts
    CopyFilesTo /usr/lib64/mozilla/native-messaging-hosts
    CopyFilesTo /usr/share/mozilla/native-messaging-hosts
fi

rm ./nordpass.json
green='\033[0;32m'
nc='\033[0m'
echo -e "${green}Installation successful${nc}"
